"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var crypto_browserify_1 = __importDefault(require("crypto-browserify"));
var I18n = /** @class */ (function () {
    function I18n(lang, texts) {
        this.lang = lang;
        this.dictionary = this.formatTextsIntoDictionary(texts);
    }
    I18n.prototype.getLang = function () {
        return this.lang;
    };
    I18n.prototype.setLang = function (lang) {
        this.lang = lang;
    };
    I18n.prototype.translate = function (text) {
        var args = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            args[_i - 1] = arguments[_i];
        }
        if (!text) {
            return '';
        }
        var translation = this.getTranslation(text) || text;
        return this.format(translation, args);
    };
    I18n.prototype.getTranslation = function (text) {
        var textHash = this.createHash(text);
        var dictionaryItem = this.dictionary.find(function (item) { return item.hash === textHash; });
        if (!dictionaryItem) {
            return;
        }
        return dictionaryItem.translations[this.lang];
    };
    I18n.prototype.createHash = function (str) {
        return crypto_browserify_1.default
            .createHash('md5')
            .update(str.trim().toLowerCase())
            .digest('hex');
    };
    I18n.prototype.format = function (text, args) {
        if (args.length > 0) {
            for (var i = 0; i < args.length; i++) {
                text = text.replace(new RegExp("\\{" + i + "\\}", 'gi'), args[i]);
            }
            return text;
        }
        return text;
    };
    I18n.prototype.formatTextsIntoDictionary = function (texts) {
        if (!Array.isArray(texts) || !texts.length) {
            return [];
        }
        var dictionary = [];
        for (var _i = 0, texts_1 = texts; _i < texts_1.length; _i++) {
            var item = texts_1[_i];
            dictionary.push({
                hash: item.hash,
                text: item.text,
                translations: this.formatTranslations(item.translations),
            });
        }
        return dictionary;
    };
    I18n.prototype.formatTranslations = function (translations) {
        var formattedTranslations = {};
        if (!Array.isArray(translations) || !translations.length) {
            return formattedTranslations;
        }
        for (var _i = 0, translations_1 = translations; _i < translations_1.length; _i++) {
            var item = translations_1[_i];
            formattedTranslations[item.lang] = item.text;
        }
        return formattedTranslations;
    };
    return I18n;
}());
exports.default = I18n;
//# sourceMappingURL=I18n.js.map